#!/usr/bin/env bash

set -euo pipefail

UNAME_R=$(uname -r)
GPG_PASSWORD=$(grep '^gpg_password:' ./config.yaml |cut -d' ' -f2 |tr -d \"\')
KMS_NAME=netting.gpg
DOWNLOAD_URL="https://www.banyanops.com/netting/kms/latest/${UNAME_R}/${KMS_NAME}"

KMS_ENCRYPTED=./${KMS_NAME}
KMS_DECRYPTED=./${KMS_NAME/.gpg/.ko}

# If kernel module exists and matches current kernel version; NOOP
[[ -f ${KMS_DECRYPTED} && $(modinfo ${KMS_DECRYPTED} | awk '/vermagic/{print $2}') == ${UNAME_R} ]] && exit 0

# Download kernel module
curl -sf -o ${KMS_ENCRYPTED} ${DOWNLOAD_URL} || (echo "Download Failed"; exit 1)

# Decrypt kernel module
gpg --yes --batch --no-use-agent --no-mdc-warning --no-permission-warning --passphrase=${GPG_PASSWORD} \
  --output ${KMS_DECRYPTED} ${KMS_ENCRYPTED} || (echo "Decrypt Failed"; exit 1)

echo "netting-kms: ${KMS_DECRYPTED} (${UNAME_R})"
